@@ -207,7 +207,7 @@ def objectify(params, schema, modellookup, strict=True):
     result = model_class(**params)
     modellookup.pop()
     if strict:
-        for k in schema["required"]:
+        for k in schema.get("required", []):
             if getattr(result, k) is None:
                 raise InvalidStatus("{}.{} is None. this is required.".format(model_class, k))
     assert modellookup.name_stack == []
@@ -271,7 +271,7 @@ def apply_changes_propperties(ob, params, properties, modellookup):
 
 
 def _get_primary_keys_from_object(ob):
-    return tuple(sorted(col.name for col in ob.__mapper__.primary_key))
+    return tuple(sorted(col.name for col in inspect(ob).mapper.primary_key))
 
 
 def _get_primary_keys_from_params(sub_params, primary_keys):
